Enum NodeEvent
Source pub enum NodeEvent {
MemberUp(Node, bool),
MemberDown(SocketAddr),
}
(Node, and whether it is a seed node)
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
The type of value that this handler will return.
Read more
This method is called for every message received by this actor.
The type of value that this handler will return.
Read more
This method is called for every message received by this actor.
The type of value that this message will resolved with if it is
successful.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.