pub struct ConnectionApproval {
pub addr: SocketAddr,
pub send_addr: SocketAddr,
}Fields
addr: SocketAddrsend_addr: SocketAddrTrait Implementations
Sourceimpl Handler<ConnectionApproval> for Cluster
impl Handler<ConnectionApproval> for Cluster
Sourcetype Result = ConnectionApprovalResponse
type Result = ConnectionApprovalResponse
The type of value that this handler will return. Read more
Sourcefn handle(
&mut self,
msg: ConnectionApproval,
_ctx: &mut Self::Context,
) -> ConnectionApprovalResponse
fn handle( &mut self, msg: ConnectionApproval, _ctx: &mut Self::Context, ) -> ConnectionApprovalResponse
This method is called for every message received by this actor.
Sourceimpl Message for ConnectionApproval
impl Message for ConnectionApproval
Sourcetype Result = ConnectionApprovalResponse
type Result = ConnectionApprovalResponse
The type of value that this message will resolved with if it is
successful.