SingleSeed

Struct SingleSeed 

pub struct SingleSeed { /* private fields */ }
The SingleSeed connector variant expects all nodes to have the same seed node (except the seed node itself, it has no seed node). If another node is added, it will be added to the cluster by the seed node. If a node has a different seed node, errors can occur. This variant is recommended for a fast connection setup, but it is not recommended if the seed node is not always available.

Implementations

Source

impl SingleSeed

pub fn new(own_addr: SocketAddr) -> Self